@@ -523,6 +523,18 @@ da_cat_get(guint32 key)
 
 gchar *da_cat_get_name(Category *item)
 {
+gchar *name = NULL;
+
+	if(item != NULL)
+	{
+		name = item->key == 0 ? _("(no category)") : item->name;
+	}
+	return name;
+}
+
+
+gchar *da_cat_get_fullname(Category *item)
+{
 gchar *name = NULL;
 
 	if(item != NULL)
