@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2024 Maxime DOYEN
+ *  Copyright (C) 1995-2025 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -20,7 +20,8 @@
 #ifndef __HB_CURRENCY_H__
 #define __HB_CURRENCY_H__
 
-typedef struct _currency	Currency;
+#include "hb-types.h"
+
 typedef struct _iso4217		Currency4217;
 
 
