@@ -752,24 +752,30 @@ guint32 retval;
 
 
 //used only in ledger
-void filter_preset_daterange_add_futuregap(Filter *flt, gint nbdays)
+void filter_preset_daterange_add_futuregap(Filter *flt, gboolean usrfuture)
 {
 	g_return_if_fail( flt != NULL );
 
 	DB( g_print("\n[filter] range add future gap\n") );
-	
+
+	DB( g_print(" pref=%d usrfuture=%d\n", PREFS->date_future_nbdays, usrfuture) );
+
 	flt->nbdaysfuture = 0;
+
+	if( PREFS->date_future_nbdays == 0 || !usrfuture )
+		return;
+
 	//#1840998 if future active and visible: we should always maxdate to today + nbdays
 	if( filter_preset_daterange_future_enable(flt, flt->range) )
 	{
-	guint32 jforcedmax = GLOBALS->today + nbdays;
+	guint32 jforcedmax = GLOBALS->today + PREFS->date_future_nbdays;
 
 		if( flt->maxdate < jforcedmax )
 			flt->nbdaysfuture = jforcedmax - flt->maxdate;
 		//else
-		//	filter->nbdaysfuture = nbdays;
+		//	flt->nbdaysfuture = nbdays;
 
-		DB( g_print(" today=%d, tmpmax=%d, nbdays=%d\n final=%d", GLOBALS->today, jforcedmax, nbdays, flt->nbdaysfuture) );
+		DB( g_print(" today=%d, tmpmax=%d, nbdays=%d\n final=%d\n", GLOBALS->today, jforcedmax, PREFS->date_future_nbdays, flt->nbdaysfuture) );
 	}
 }
 
@@ -1012,6 +1018,11 @@ void filter_preset_type_set(Filter *flt, gint type, gint mode)
 				flt->typ_xexp = TRUE;
 				flt->typ_xinc = TRUE;
 				break;
+			case FLT_TYPE_NOTXFER:
+				flt->typ_xexp = TRUE;
+				flt->typ_xinc = TRUE;
+				flt->option[FLT_GRP_TYPE] = FLT_EXCLUDE;
+				break;
 		}
 	}
 
@@ -1285,7 +1296,8 @@ Payee *payitem;
 	{
 	gchar formatd_buf[G_ASCII_DTOSTR_BUF_SIZE];
 	
-		hb_strfnum(formatd_buf, G_ASCII_DTOSTR_BUF_SIZE-1, arc->amount, GLOBALS->kcur, FALSE);
+		//2127104 was hb_strfnum
+		hb_strfmon(formatd_buf, G_ASCII_DTOSTR_BUF_SIZE-1, arc->amount, GLOBALS->kcur, FALSE);
 		retval |= hb_string_utf8_strstr(formatd_buf, needle, FALSE);
 	}
 
@@ -1455,9 +1467,9 @@ gchar *tags;
 	{
 	gchar formatd_buf[G_ASCII_DTOSTR_BUF_SIZE];
 
+		//2127104 was hb_strfnum
+		hb_strfmon(formatd_buf, G_ASCII_DTOSTR_BUF_SIZE-1, txn->amount, txn->kcur, FALSE);
 		DB( g_print(" needle='%s' txnamt='%s'\n", needle, formatd_buf) );
-		
-		hb_strfnum(formatd_buf, G_ASCII_DTOSTR_BUF_SIZE-1, txn->amount, txn->kcur, FALSE);
 		retval |= hb_string_utf8_strstr(formatd_buf, needle, FALSE);
 	}
 
