@@ -119,6 +119,7 @@ enum
 	FLT_TYPE_EXPENSE = 2,
 	FLT_TYPE_INCOME = 3,
 	FLT_TYPE_INTXFER = 4,
+	FLT_TYPE_NOTXFER = 5,
 };
 
 
@@ -232,7 +233,7 @@ void filter_preset_type_set(Filter *flt, gint type, gint mode);
 gboolean filter_preset_daterange_future_enable(Filter *flt, gint range);
 
 guint32 filter_get_maxdate_forecast(Filter *filter);
-void filter_preset_daterange_add_futuregap(Filter *filter, gint nbdays);
+void filter_preset_daterange_add_futuregap(Filter *filter, gboolean usrfuture);
 
 void filter_set_tag_by_id(Filter *flt, guint32 key);
 void filter_preset_status_set(Filter *flt, gint value);
