@@ -316,8 +316,10 @@ da_pay_get(guint32 key)
 	return g_hash_table_lookup(GLOBALS->h_pay, &key);
 }
 
-
-//gchar *da_pay_get_name(Payee *item)
+gchar *da_pay_get_name(Payee *item)
+{
+	return (item->key == 0) ? _("(no payee)") : item->name;
+}
 
 
 void da_pay_consistency(Payee *item)
