@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2024 Maxime DOYEN
+ *  Copyright (C) 1995-2025 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -20,7 +20,7 @@
 #ifndef __HB_PAYEE_H__
 #define __HB_PAYEE_H__
 
-typedef struct _payee		Payee;
+#include "hb-types.h"
 
 struct _payee
 {
@@ -55,6 +55,7 @@ gboolean da_pay_append(Payee *acc);
 Payee *da_pay_append_if_new(gchar *rawname);
 
 Payee *da_pay_get(guint32 key);
+gchar *da_pay_get_name(Payee *item);
 Payee *da_pay_get_by_name(gchar *rawname);
 
 void da_pay_consistency(Payee *item);
