@@ -585,7 +585,7 @@ guint idx = 0;
 		if( dr != NULL )
 		{
 			dr->pos   = idx;
-			dr->label = g_strdup( (cat->key == 0) ? _("(no category)") : cat->name );
+			dr->label = g_strdup( da_cat_get_name(cat) );
 			//dt->keyindex[cat->key] = idx;
 			datatable_set_keyindex(dt, cat->key, idx);
 			
@@ -628,7 +628,7 @@ guint idx = 0;
 		if( dr != NULL )
 		{
 			dr->pos   = idx;
-			dr->label = g_strdup( (pay->key == 0) ? _("(no payee)") : pay->name );
+			dr->label = g_strdup( da_pay_get_name(pay) );
 			DB2( g_print(" +pay k:%d, idx:%d '%s'\n", pay->key, idx, dr->label) );
 			//store transpose
 			//dt->keyindex[pay->key] = idx;
