@@ -957,12 +957,14 @@ Account *acc;
 		child->date		= s_txn->date;
 
 	//#2019193 option the sync xfer status
-	if( PREFS->xfer_syncstat == TRUE )
+	//#2125300 overide if TXN_STATUS_VOID 
+	if( (PREFS->xfer_syncstat == TRUE) || (s_txn->status == TXN_STATUS_VOID) )
 	{
 		//#2111359 remind status not synced
 		child->flags &= ~(OF_REMIND);
 		if(s_txn->flags & OF_REMIND)
 			child->flags |= OF_REMIND;
+
 		child->status = s_txn->status;
 		child->dspflags |= FLAG_TMP_EDITED;
 	}	
