@@ -30,7 +30,7 @@
 #include <libintl.h>	/* gettext */
 #include <locale.h>
 #include <stdlib.h>		/* atoi, atof, atol */
-#include <string.h>		/* memset, memcpy, strcmp, strcpy */
+#include <string.h>		/* memset, memcpy, strcasestr, strcmp, strcpy */
 //#include <time.h>
 
 #include <glib.h>
@@ -81,13 +81,13 @@
 
 #define HOMEBANK_MAJOR	5
 #define HOMEBANK_MINOR	9
-#define HOMEBANK_MICRO	5
+#define HOMEBANK_MICRO	7
 
-#define HB_VERSION		"5.9.5"
+#define HB_VERSION		"5.9.7"
 #define HB_VERSION_NUM	(HOMEBANK_MAJOR*10000) + (HOMEBANK_MINOR*100) + HOMEBANK_MICRO
 
 #define FILE_VERSION		1.6
-#define PREF_VERSION		595
+
 
 #if HB_UNSTABLE == FALSE
 	#define	PROGNAME		"HomeBank"
