@@ -623,7 +623,7 @@ GString *node;
 
 	//g_print ("Action %s activated\n", g_action_get_name (G_ACTION (action)));
 
-	node = lst_sch_widget_to_string(GTK_TREE_VIEW(data->LV_upc), HB_STRING_PRINT);
+	node = lst_sch_widget_to_string(GTK_TREE_VIEW(data->LV_upc), HB_STRING_CLIPBOARD);
 
 	clipboard = gtk_clipboard_get_default(gdk_display_get_default());
 	gtk_clipboard_set_text(clipboard, node->str, node->len);
@@ -729,7 +729,8 @@ GtkWidget *image;
 	g_object_unref (section);
 
 	GSimpleActionGroup *group = g_simple_action_group_new ();
-	data->action_group_acc = group;
+	//2130483 stupid overwrite here
+	//data->action_group_acc = group;
 	g_action_map_add_action_entries (G_ACTION_MAP (group), actions, G_N_ELEMENTS (actions), data);
 
 	bbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
