@@ -50,11 +50,40 @@ gchar *ui_arc_listview_get_freq_label(gint index)
 	return "";
 }
 
+static guint32
+_arc_get_curr(Archive *arc, gint expinc)
+{
+Account *acc = NULL;
+guint32 kcur = GLOBALS->kcur;
+
+	if( arc != NULL ) /* display total */
+	{
+		if(arc->flags & OF_INTXFER)
+		{
+			//-1 = expense
+			if( expinc == -1)
+				acc = da_acc_get(arc->kacc);
+			else
+				acc = da_acc_get(arc->kxferacc);
+		}
+		else
+		{
+			acc = da_acc_get(arc->kacc);
+		}
+	}
+
+	if(acc != NULL)
+		kcur = acc->kcur;
+
+	return kcur;
+}
+
+
 
 /* = = = = = = = = = = = = = = = = */
 
 
-static void lst_sch_widget_to_string_row(GString *node, gchar sep, GtkTreeModel *model, GtkTreeIter *iter, guint flags)
+static void lst_sch_widget_to_string_row(GString *node, ToStringMode mode, gchar sep, GtkTreeModel *model, GtkTreeIter *iter, guint flags)
 {
 gchar strbuf[G_ASCII_DTOSTR_BUF_SIZE];
 gdouble expense, income;
@@ -71,6 +100,7 @@ gchar *memo;
 		LST_DSPUPC_MEMO, &memo,
 		-1);
 
+	DB( g_print("---- %p\n", arc) );
 
 
 	DB( g_print("---- %p\n", arc) );
@@ -111,10 +141,13 @@ gchar *memo;
 	}
 	g_string_append_c (node, sep );
 
+	guint32 kcur = _arc_get_curr(arc, (expense < 0) ? -1 : 0);
+
 	//expense
 	if(expense < 0)
 	{
-		g_snprintf(strbuf, sizeof (strbuf), "%.2f", expense);
+		//g_snprintf(strbuf, sizeof (strbuf), "%.2f", expense);
+		hb_strfmon(strbuf, G_ASCII_DTOSTR_BUF_SIZE-1, expense, kcur, FALSE);
 		g_string_append(node, strbuf);
 	}
 	g_string_append_c (node, sep );
@@ -122,7 +155,8 @@ gchar *memo;
 	//income
 	if(income > 0)
 	{
-		g_snprintf(strbuf, sizeof (strbuf), "%.2f", income);
+		//g_snprintf(strbuf, sizeof (strbuf), "%.2f", income);
+		hb_strfmon(strbuf, G_ASCII_DTOSTR_BUF_SIZE-1, income, kcur, FALSE);
 		g_string_append(node, strbuf);
 	}
 	g_string_append_c (node, sep );
@@ -151,8 +185,6 @@ GString *node;
 GtkTreeModel *model;
 GtkTreeIter	iter;
 gboolean valid;
-guint32 nbcols, i;
-gint uid;
 gchar sep;
 
 	DB( g_print("\n[lst_sch] to string\n") );
@@ -162,43 +194,21 @@ gchar sep;
 	sep = (mode == HB_STRING_PRINT) ? '\t' : ';';
 
 	// header (nbcols-2 for icon column)
-	nbcols = gtk_tree_view_get_n_columns (treeview) - 1;
-	for( i=1 ; i < nbcols ; i++ )
-	{
-	GtkTreeViewColumn *column = gtk_tree_view_get_column (treeview, i);
-	
-		//todo: ? restrict to visibility
-		if( GTK_IS_TREE_VIEW_COLUMN(column) )
-		{
-			if( gtk_tree_view_column_get_visible(column))
-			{
-				//skip columns
-				uid = GPOINTER_TO_UINT(g_object_get_data(G_OBJECT(column), "uid"));
-				if(	
-					uid == COL_SCH_UID_PAYNUMBER
-				||  uid == COL_SCH_UID_CATEGORY
-				||  uid == COL_SCH_UID_CLR
-
-				)
-				continue;
-
-				/*uid = GPOINTER_TO_UINT(g_object_get_data(G_OBJECT(column), "uid"));
-				switch(uid)
-				{
-					case COL_DSPACC_RECON : flags |= LST_TXN_ACC_REC; break;
-					case COL_DSPACC_CLEAR : flags |= LST_TXN_ACC_CLR; break;
-					case COL_DSPACC_TODAY : flags |= LST_TXN_ACC_TOD; break;
-					case COL_DSPACC_FUTURE: flags |= LST_TXN_ACC_FUT; break;
-				}*/
-				
-				g_string_append(node, gtk_tree_view_column_get_title (column));
-				if( i < nbcols-1 )
-				{
-					g_string_append_c(node, sep);
-				}
-			}
-		}
-	}
+	g_string_append(node, _("Late"));
+	g_string_append_c(node, sep);
+	g_string_append(node, _("Still"));
+	g_string_append_c(node, sep);
+	g_string_append(node, _("Next date"));
+	g_string_append_c(node, sep);
+	g_string_append(node, _("Payee"));
+	g_string_append_c(node, sep);
+	g_string_append(node, _("Expense"));
+	g_string_append_c(node, sep);
+	g_string_append(node, _("Income"));
+	g_string_append_c(node, sep);
+	g_string_append(node, _("Memo"));
+	g_string_append_c(node, sep);
+	g_string_append(node, _("Account"));
 	g_string_append_c(node, '\n');
 
 	//lines
@@ -206,7 +216,7 @@ gchar sep;
 	valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(model), &iter);
 	while (valid)
 	{
-		lst_sch_widget_to_string_row(node, sep, model, &iter, 0);
+		lst_sch_widget_to_string_row(node, mode, sep, model, &iter, 0);
 		valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(model), &iter);
 	}
 
@@ -455,26 +465,7 @@ gint weight;
 		
 	if( amount != 0.0 )
 	{
-	Account *acc = NULL;
-	guint32 kcur = GLOBALS->kcur;
-
-		if( arc != NULL ) /* display total */
-		{
-			if(arc->flags & OF_INTXFER)
-			{
-				if( column == -1)
-					acc = da_acc_get(arc->kacc);
-				else
-					acc = da_acc_get(arc->kxferacc);
-			}
-			else
-			{
-				acc = da_acc_get(arc->kacc);
-			}
-		}
-
-		if(acc != NULL)
-			kcur = acc->kcur;
+	guint32	kcur = _arc_get_curr(arc, column);
 
 		hb_strfmon(buf, G_ASCII_DTOSTR_BUF_SIZE-1, amount, kcur, GLOBALS->minor);
 
