@@ -94,7 +94,7 @@ gint fulfilled;
 		if( catitem != NULL )
 		{
 			g_free(name);
-			name = g_strdup( (catitem->key == 0) ? _("(no category)") : catitem->fullname );
+			name = g_strdup( da_cat_get_fullname(catitem) );
 		}
 	}
 
@@ -2106,7 +2106,7 @@ static void repbudget_window_setup(struct repbudget_data *data)
 
 
 	DB( g_print(" set widgets default\n") );
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->BT_detail), PREFS->budg_showdetail);
+	gtk_toggle_tool_button_set_active(GTK_TOGGLE_TOOL_BUTTON(data->BT_detail), PREFS->budg_showdetail);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_minor),GLOBALS->minor);
 
 	g_object_set_data(G_OBJECT(gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_report))), "minor", (gpointer)data->CM_minor);
