@@ -1399,7 +1399,26 @@ gboolean visible;
 		gtk_widget_set_tooltip_text (GTK_WIDGET(txndata->LB_acc_title), label);
 		gtk_widget_set_tooltip_text (GTK_WIDGET(txndata->LB_acc_info), label);
 		g_free(label);
+
+		//#2111468 add error log
+		visible = genfile->n_error > 0 ? TRUE : FALSE;
+		hb_widget_visible(GTK_WIDGET(txndata->EX_log), visible);
+		if( genfile->errlog )
+		{
+		GtkTextBuffer *buffer;
+		GtkTextIter iter;
 		
+			label = g_strdup_printf(_("%d invalid lines were skipped"), genfile->n_error);
+			gtk_expander_set_label(GTK_EXPANDER(txndata->EX_log), label);
+			g_free(label);
+			gtk_expander_set_expanded(GTK_EXPANDER(txndata->EX_log), TRUE);
+
+			buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (txndata->TV_log));
+			gtk_text_buffer_set_text (buffer, "", 0);
+			gtk_text_buffer_get_iter_at_offset (buffer, &iter, 0);
+			gtk_text_buffer_insert (buffer, &iter, genfile->errlog, -1);	
+		}
+
 		//label = g_strdup_printf(_("Account %d of %d"), acckey+1, nbacc);
 		//gtk_label_set_markup (GTK_LABEL(txndata->LB_acc_count), label);
 		//g_free(label);
@@ -1849,6 +1868,23 @@ gint row;
 		txndata->LB_txn = label;
 		gtk_box_prepend (GTK_BOX (box), label);
 
+	//#2111468 add error log
+	row++;
+	expander = gtk_expander_new_with_mnemonic(_("Error log"));
+	txndata->EX_log = expander;
+	gtk_widget_set_hexpand(expander, TRUE);
+	gtk_grid_attach (GTK_GRID (table), expander, 0, row, 2, 1);
+
+	label = gtk_text_view_new();
+	txndata->TV_log = label;
+    scrollwin = make_scrolled_window(GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+    gtk_widget_set_size_request (scrollwin, -1, 128);
+	gtk_scrolled_window_set_child (GTK_SCROLLED_WINDOW(scrollwin), label);
+	//gtk_widget_set_hexpand (scrollwin, TRUE);
+	//gtk_widget_set_vexpand (scrollwin, TRUE);
+	gtk_expander_set_child(GTK_EXPANDER(expander), scrollwin);
+	//hb_widget_set_margin(GTK_WIDGET(scrollwin), SPACING_MEDIUM);
+
 	row++;
 	scrollwin = make_scrolled_window(GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 	treeview = list_txn_import_create();
