@@ -115,11 +115,7 @@ gchar type;
 
 	gtk_tree_model_get(model, iter, LST_DEFCAT_DATAS, &entry, -1);
 
-	if(entry->key == 0)
-		name = g_strdup(_("(no category)"));
-	else
-		name = entry->name;
-
+	name = da_cat_get_name(entry);
 	type = category_get_type_char(entry);
 
 	if(entry->key == 0)
