@@ -639,16 +639,9 @@ ui_pay_listview_name_cell_data_function (GtkTreeViewColumn *col,
 				gpointer user_data)
 {
 Payee *entry;
-gchar *name;
 
 	gtk_tree_model_get(model, iter, LST_DEFPAY_DATAS, &entry, -1);
-
-	if(entry->key == 0)
-		name = _("(no payee)");
-	else
-		name = entry->name;
-
-	g_object_set(renderer, "text", name, NULL);
+	g_object_set(renderer, "text", da_pay_get_name(entry), NULL);
 }
 
 
