@@ -1276,9 +1276,25 @@ gchar buf[HB_KV_BUFFER_MAX_LEN];
 GtkWidget *hbtk_combo_box_new (GtkWidget *label)
 {
 GtkWidget *combobox;
+GList *renderers, *list;
 
 	combobox = gtk_combo_box_text_new();
-	
+
+	//#2131030 add ellipsise to renderer for template
+	renderers = gtk_cell_layout_get_cells (GTK_CELL_LAYOUT(combobox));
+	if(g_list_length(renderers) == 1)
+	{
+		list = g_list_first(renderers);
+		if(GTK_IS_CELL_RENDERER(list->data))
+		{
+			g_object_set(GTK_CELL_RENDERER(list->data), 
+				"ellipsize", PANGO_ELLIPSIZE_END,
+				"ellipsize-set", TRUE,
+				NULL);
+		}	
+	}
+	g_list_free(renderers);
+
 	if(label)
 		gtk_label_set_mnemonic_widget (GTK_LABEL(label), combobox);
 
